pub struct FvmVolume { /* private fields */ }Expand description
A wrapper around an opened volume in an FVM instance. This keeps the volume alive and provides access to its block connector.
Implementations
Sourceimpl FvmVolume
impl FvmVolume
Sourcepub fn new(serving_volume: ServingVolume, guid: Guid) -> Self
pub fn new(serving_volume: ServingVolume, guid: Guid) -> Self
Creates a new FvmVolume wrapping the given ServingVolume and Guid.
pub fn guid(&self) -> &Guid
pub fn block_connector(&self) -> DirBasedBlockConnector